potential\_flow package
===================================

.. automodule:: IMTreatment.potential_flow
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

   IMTreatment.potential_flow.potential_flow

